@@ -15,7 +15,7 @@ public:
   Something();
 
 protected:
-  virtual void on_print(int a);
+  void on_print(int a);
 
   using type_signal_print = sigc::signal<void(int)>;
   type_signal_print signal_print;
@@ -35,7 +35,7 @@ Something::Something()
 void
 Something::on_print(int a)
 {
-  std::cout << "on_print recieved: " << a << std::endl;
+  std::cout << "on_print received: " << a << std::endl;
 }
 
 int
