@@ -3,11 +3,8 @@
  */
 
 #include "testutilities.h"
-#include <sstream>
-#include <cstdlib>
 #include <sigc++/trackable.h>
 #include <sigc++/functors/slot.h>
-#include <sigc++/functors/mem_fun.h>
 
 namespace
 {
@@ -16,7 +13,7 @@ std::ostringstream result_stream;
 class my_class : public sigc::trackable
 {
 public:
-  int i;
+  int i = 0;
 
   void foo() { result_stream << i; }
 };
